@@ -2,8 +2,8 @@ import pandas as pd
 
 from airflow_commons.glossary import COMMA
 from airflow_commons.logger import LOGGER
-from airflow_commons.sql_resources.bigquery import (
-    DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE,
+from airflow_commons.resources.bigquery import (
+    DEDUPLICATION_GET_AVAILABLE_PARTITIONS_FIELD_SQL_FILE,
     ARCHIVE_SOURCE_STATEMENT_FILE,
     ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
 )
@@ -90,10 +90,10 @@ def deduplicate(
         client, target_dataset, target_table
     )
     if allow_partition_pruning:
-        partition_pruning_params["oldest_target_partition"] = single_value_select(
+        partition_pruning_params["available_target_partitions"] = single_value_select(
             client=client,
             sql=read_sql(
-                sql_file=DEDUPLICATION_GET_OLDEST_PARTITION_FIELD_SQL_FILE,
+                sql_file=DEDUPLICATION_GET_AVAILABLE_PARTITIONS_FIELD_SQL_FILE,
                 project_id=project_id,
                 source_dataset=source_dataset,
                 source_table=source_table,
@@ -106,7 +106,7 @@ def deduplicate(
                 oldest_allowable_target_partition=oldest_allowable_target_partition,
             ),
         )
-        if partition_pruning_params["oldest_target_partition"] is None:
+        if partition_pruning_params["available_target_partitions"] is None:
             LOGGER.info(
                 f"There is no data: - {project_id}.{source_dataset}.{source_table} - between [{start_date} - {end_date}] ."
             )
