@@ -3,7 +3,7 @@ from datetime import datetime
 import json
 
 from airflow_commons.logger import LOGGER
-from airflow_commons.sql_resources.bigquery import (
+from airflow_commons.resources.bigquery import (
     GET_COLUMN_NAMES_SQL_FILE,
     GET_TABLE_NAMES_SQL_FILE,
     GET_PRIMITIVE_COLUMN_NAMES_SQL_FILE,
