@@ -1,8 +1,8 @@
 from airflow_commons.utils.file_utils import read_sql
-from airflow_commons.sql_resources.mysql import DELETE_SQL_FILE
-from airflow_commons.sql_resources.mysql import SELECT_ALL_SQL_FILE
-from airflow_commons.sql_resources.mysql import SELECT_SQL_FILE
-from airflow_commons.sql_resources.mysql import GET_ROW_COUNT_SQL_FILE
+from airflow_commons.resources.mysql import DELETE_SQL_FILE
+from airflow_commons.resources.mysql import SELECT_ALL_SQL_FILE
+from airflow_commons.resources.mysql import SELECT_SQL_FILE
+from airflow_commons.resources.mysql import GET_ROW_COUNT_SQL_FILE
 
 
 def get_delete_sql(
